@@ -1,13 +1,13 @@
 use crate::ffi_types::{c_char, c_int};
 
 #[allow(clippy::upper_case_acronyms)]
-
 pub type BOTAN_FFI_ERROR = c_int;
 
 pub const BOTAN_FFI_SUCCESS: BOTAN_FFI_ERROR = 0;
 pub const BOTAN_FFI_INVALID_VERIFIER: BOTAN_FFI_ERROR = 1;
 pub const BOTAN_FFI_ERROR_INVALID_INPUT: BOTAN_FFI_ERROR = -1;
 pub const BOTAN_FFI_ERROR_BAD_MAC: BOTAN_FFI_ERROR = -2;
+pub const BOTAN_FFI_ERROR_NO_VALUE: BOTAN_FFI_ERROR = -3;
 pub const BOTAN_FFI_ERROR_INSUFFICIENT_BUFFER_SPACE: BOTAN_FFI_ERROR = -10;
 pub const BOTAN_FFI_ERROR_STRING_CONVERSION_ERROR: BOTAN_FFI_ERROR = -11;
 pub const BOTAN_FFI_ERROR_EXCEPTION_THROWN: BOTAN_FFI_ERROR = -20;
@@ -30,7 +30,7 @@ extern "C" {
 
     pub fn botan_error_description(err: BOTAN_FFI_ERROR) -> *const c_char;
 
-    #[cfg(feature = "botan3")]
+    #[cfg(botan_ffi_20230403)]
     pub fn botan_error_last_exception_message() -> *const c_char;
 
 }
