@@ -7,8 +7,7 @@ use botan_sys::*;
 #[test]
 fn test_hex() {
     let bin = vec![0x42, 0x23, 0x45, 0x8F];
-    let mut out = Vec::new();
-    out.resize(bin.len() * 2, 0);
+    let mut out = vec![0; bin.len() * 2];
 
     unsafe {
         assert_eq!(
@@ -48,7 +47,7 @@ fn test_hash() {
         let hash_name = CString::new("SHA-384").unwrap();
         assert_eq!(botan_hash_init(&mut hash, hash_name.as_ptr(), 0u32), 0);
 
-        let input = vec![97, 98, 99];
+        let input = [97, 98, 99];
         assert_eq!(botan_hash_update(hash, input.as_ptr(), input.len()), 0);
         assert_eq!(botan_hash_update(hash, input.as_ptr(), input.len()), 0);
 
@@ -74,20 +73,6 @@ fn test_version() {
 
         assert!(botan_ffi_supports_api(api_version) == 0);
         assert!(botan_ffi_supports_api(api_version + 1) != 0);
-
-        #[cfg(feature = "botan3")]
-        {
-            assert_eq!(botan_version_major(), 3);
-        }
-
-        #[cfg(not(feature = "botan3"))]
-        {
-            if botan_version_major() == 2 {
-                assert!(botan_version_minor() > 8);
-            } else {
-                assert_eq!(botan_version_major(), 3);
-            }
-        }
     }
 }
 
